@@ -2,11 +2,15 @@ package YAML::LibYAML::API::XS;
 use strict;
 use warnings;
 
-our $VERSION = '0.001_003'; # TRIAL VERSION
+our $VERSION = '0.002_001'; # TRIAL VERSION
 
 use XSLoader;
 XSLoader::load('YAML::LibYAML::API::XS', $VERSION);
 
+sub parse_events {
+    parse_string_events(@_);
+}
+
 1;
 
 __END__
